@@ -171,7 +171,7 @@ sub do_import {
     if($spec->{INIT_META}){
         my $meta;
         foreach my $init_meta(@{$spec->{INIT_META}}){
-            $meta = $into->$init_meta(for_class => $into);
+            $meta = $package->$init_meta(for_class => $into);
         }
 
         if(@traits){
@@ -183,9 +183,11 @@ sub do_import {
                 } @traits;
 
             require Mouse::Util::MetaRole;
-            Mouse::Util::MetaRole::apply_metaclass_roles(
-                for_class       => $into,
-                metaclass_roles => \@traits,
+            Mouse::Util::MetaRole::apply_metaroles(
+                for       => $into,
+                Mouse::Util::is_a_metarole($into->meta)
+                    ? (role_metaroles  => { role  => \@traits })
+                    : (class_metaroles => { class => \@traits }),
             );
         }
     }
@@ -225,6 +227,7 @@ sub do_unimport {
     };
 
     for my $keyword (@{ $spec->{REMOVABLES} }) {
+        next if !exists $stash->{$keyword};
         my $gv = \$stash->{$keyword};
         if(ref($gv) eq 'GLOB' && *{$gv}{CODE} == $spec->{EXPORTS}{$keyword}){ # make sure it is from us
             delete $stash->{$keyword};
@@ -233,27 +236,24 @@ sub do_unimport {
     return;
 }
 
-# 1 extra level because it's called by import so there's a layer
-# of indirection
-sub _LEVEL(){ 1 }
-
 sub _get_caller_package {
     my($arg) = @_;
 
+    # We need one extra level because it's called by import so there's a layer
+    # of indirection
     if(ref $arg){
         return defined($arg->{into})       ? $arg->{into}
-             : defined($arg->{into_level}) ? scalar caller(_LEVEL + $arg->{into_level})
-             :                               scalar caller(_LEVEL);
+             : defined($arg->{into_level}) ? scalar caller(1 + $arg->{into_level})
+             :                               scalar caller(1);
     }
     else{
-        return scalar caller(_LEVEL);
+        return scalar caller(1);
     }
 }
 
 #sub _spec{ %SPEC }
 
 1;
-
 __END__
 
 =head1 NAME
@@ -262,7 +262,7 @@ Mouse::Exporter - make an import() and unimport() just like Mouse.pm
 
 =head1 VERSION
 
-This document describes Mouse version 0.40_09
+This document describes Mouse version 0.50_01
 
 =head1 SYNOPSIS
 
