@@ -5,156 +5,88 @@ use Carp ();
 
 use Mouse::Meta::TypeConstraint;
 
-#use Mouse::Meta::Method::Accessor;
-use Mouse::Meta::Method::Delegation;
+my %valid_options = map { $_ => undef } (
+  'accessor',
+  'auto_deref',
+  'builder',
+  'clearer',
+  'coerce',
+  'default',
+  'documentation',
+  'does',
+  'handles',
+  'init_arg',
+  'is',
+  'isa',
+  'lazy',
+  'lazy_build',
+  'name',
+  'predicate',
+  'reader',
+  'required',
+  'traits',
+  'trigger',
+  'type_constraint',
+  'weak_ref',
+  'writer',
 
+  # internally used
+  'associated_class',
+  'associated_methods',
 
-sub _process_options{
-    my($class, $name, $args) = @_;
+  # Moose defines, but Mouse doesn't
+  #'definition_context',
+  #'initializer',
+  #'insertion_order',
 
+  # special case for AttributeHelpers
+  'provides',
+  'curries',
+);
+
+sub new {
+    my $class = shift;
+    my $name  = shift;
+
+    my $args  = $class->Mouse::Object::BUILDARGS(@_);
 
     # XXX: for backward compatibility (with method modifiers)
     if($class->can('canonicalize_args') != \&canonicalize_args){
         %{$args} = $class->canonicalize_args($name, %{$args});
     }
 
-    # taken from Class::MOP::Attribute::new
+    $class->_process_options($name, $args);
 
-    defined($name)
-        or $class->throw_error('You must provide a name for the attribute');
+    $args->{name} = $name;
 
-    if(!exists $args->{init_arg}){
-        $args->{init_arg} = $name;
+    # check options
+    # (1) known by core
+    my @bad = grep{ !exists $valid_options{$_} } keys %{$args};
+
+    # (2) known by subclasses
+    if(@bad && $class ne __PACKAGE__){
+        my %valid_attrs = (
+            map { $_ => undef }
+            grep { defined }
+            map { $_->init_arg() }
+            $class->meta->get_all_attributes()
+        );
+        @bad = grep{ !exists $valid_attrs{$_} } @bad;
     }
 
-    # 'required' requires eigher 'init_arg', 'builder', or 'default'
-    my $can_be_required = defined( $args->{init_arg} );
-
-    if(exists $args->{builder}){
-        # XXX:
-        # Moose refuses a CODE ref builder, but Mouse doesn't for backward compatibility
-        # This feature will be changed in a future. (gfx)
-        $class->throw_error('builder must be a defined scalar value which is a method name')
-            #if ref $args->{builder} || !defined $args->{builder};
-            if !defined $args->{builder};
-
-        $can_be_required++;
-    }
-    elsif(exists $args->{default}){
-        if(ref $args->{default} && ref($args->{default}) ne 'CODE'){
-            $class->throw_error("References are not allowed as default values, you must "
-                              . "wrap the default of '$name' in a CODE reference (ex: sub { [] } and not [])");
-        }
-        $can_be_required++;
+    # (3) bad options found
+    if(@bad){
+        @bad = sort @bad;
+        Carp::cluck("Found unknown argument(s) passed to '$name' attribute constructor in '$class': @bad");
     }
 
-    if( $args->{required} && !$can_be_required ) {
-        $class->throw_error("You cannot have a required attribute ($name) without a default, builder, or an init_arg");
-    }
-
-    # taken from Mouse::Meta::Attribute->new and _process_args->
-
-    if(exists $args->{is}){
-        my $is = $args->{is};
-
-        if($is eq 'ro'){
-            $args->{reader} ||= $name;
-        }
-        elsif($is eq 'rw'){
-            if(exists $args->{writer}){
-                $args->{reader} ||= $name;
-             }
-             else{
-                $args->{accessor} ||= $name;
-             }
-        }
-        elsif($is eq 'bare'){
-            # do nothing, but don't complain (later) about missing methods
-        }
-        else{
-            $is = 'undef' if !defined $is;
-            $class->throw_error("I do not understand this option (is => $is) on attribute ($name)");
-        }
-    }
-
-    my $tc;
-    if(exists $args->{isa}){
-        $args->{type_constraint} = Mouse::Util::TypeConstraints::find_or_create_isa_type_constraint($args->{isa});
-    }
-    elsif(exists $args->{does}){
-        $args->{type_constraint} = Mouse::Util::TypeConstraints::find_or_create_does_type_constraint($args->{does});
-    }
-    $tc = $args->{type_constraint};
-
-    if($args->{coerce}){
-        defined($tc)
-            || $class->throw_error("You cannot have coercion without specifying a type constraint on attribute ($name)");
-
-        $args->{weak_ref}
-            && $class->throw_error("You cannot have a weak reference to a coerced value on attribute ($name)");
-    }
-
-    if ($args->{lazy_build}) {
-        exists($args->{default})
-            && $class->throw_error("You can not use lazy_build and default for the same attribute ($name)");
-
-        $args->{lazy}      = 1;
-        $args->{builder} ||= "_build_${name}";
-        if ($name =~ /^_/) {
-            $args->{clearer}   ||= "_clear${name}";
-            $args->{predicate} ||= "_has${name}";
-        }
-        else {
-            $args->{clearer}   ||= "clear_${name}";
-            $args->{predicate} ||= "has_${name}";
-        }
-    }
-
-    if ($args->{auto_deref}) {
-        defined($tc)
-            || $class->throw_error("You cannot auto-dereference without specifying a type constraint on attribute ($name)");
-
-        ( $tc->is_a_type_of('ArrayRef') || $tc->is_a_type_of('HashRef') )
-            || $class->throw_error("You cannot auto-dereference anything other than a ArrayRef or HashRef on attribute ($name)");
-    }
-
-    if (exists $args->{trigger}) {
-        ('CODE' eq ref $args->{trigger})
-            || $class->throw_error("Trigger must be a CODE ref on attribute ($name)");
-    }
-
-    if ($args->{lazy}) {
-        (exists $args->{default} || defined $args->{builder})
-            || $class->throw_error("You cannot have lazy attribute ($name) without specifying a default value for it");
-    }
-
-    return;
-}
-
-sub new {
-    my $class = shift;
-    my $name  = shift;
-
-    my %args  = (@_ == 1) ? %{ $_[0] } : @_;
-
-    $class->_process_options($name, \%args);
-
-    $args{name} = $name;
-
-    my $self = bless \%args, $class;
+    my $self = bless $args, $class;
 
     # extra attributes
     if($class ne __PACKAGE__){
-        $class->meta->_initialize_object($self, \%args);
+        $class->meta->_initialize_object($self, $args);
     }
 
-# XXX: there is no fast way to check attribute validity
-#    my @bad = ...;
-#    if(@bad){
-#        @bad = sort @bad;
-#        Carp::cluck("Found unknown argument(s) passed to '$name' attribute constructor in '$class': @bad");
-#    }
-
     return $self;
 }
 
@@ -204,8 +136,7 @@ sub canonicalize_args{ # DEPRECATED
     my ($self, $name, %args) = @_;
 
     Carp::cluck("$self->canonicalize_args has been deprecated."
-        . "Use \$self->_process_options instead.")
-            if Mouse::Util::_MOUSE_VERBOSE;
+        . "Use \$self->_process_options instead.");
 
     return %args;
 }
@@ -214,8 +145,7 @@ sub create { # DEPRECATED
     my ($self, $class, $name, %args) = @_;
 
     Carp::cluck("$self->create has been deprecated."
-        . "Use \$meta->add_attribute and \$attr->install_accessors instead.")
-            if Mouse::Util::_MOUSE_VERBOSE;
+        . "Use \$meta->add_attribute and \$attr->install_accessors instead.");
 
     # noop
     return $self;
@@ -243,37 +173,41 @@ sub verify_against_type_constraint {
     return 1 if !$type_constraint;
     return 1 if $type_constraint->check($value);
 
-    $self->verify_type_constraint_error($self->name, $value, $type_constraint);
+    $self->_throw_type_constraint_error($value, $type_constraint);
 }
 
-sub verify_type_constraint_error {
-    my($self, $name, $value, $type) = @_;
-    $self->throw_error("Attribute ($name) does not pass the type constraint because: "
-        . $type->get_message($value));
-}
+sub _throw_type_constraint_error {
+    my($self, $value, $type) = @_;
 
-sub coerce_constraint { # DEPRECATED
-    my $type = $_[0]->{type_constraint}
-        or return $_[1];
-
-    Carp::cluck("coerce_constraint() has been deprecated, which was an internal utility anyway");
-
-    return Mouse::Util::TypeConstraints->typecast_constraints($_[0]->associated_class->name, $type, $_[1]);
+    $self->throw_error(
+        sprintf q{Attribute (%s) does not pass the type constraint because: %s},
+            $self->name,
+            $type->get_message($value),
+    );
 }
 
 sub clone_and_inherit_options{
-    my($self, %args) = @_;
+    my $self = shift;
+    my $args = $self->Mouse::Object::BUILDARGS(@_);
 
-    my($attribute_class, @traits) = ref($self)->interpolate_class(\%args);
+    my($attribute_class, @traits) = ref($self)->interpolate_class($args);
 
-    $args{traits} = \@traits if @traits;
+    $args->{traits} = \@traits if @traits;
     # do not inherit the 'handles' attribute
     foreach my $name(keys %{$self}){
-        if(!exists $args{$name} && $name ne 'handles'){
-            $args{$name} = $self->{$name};
+        if(!exists $args->{$name} && $name ne 'handles'){
+            $args->{$name} = $self->{$name};
         }
     }
-    return $attribute_class->new($self->name, %args);
+
+    # remove temporary caches
+    foreach my $attr(keys %{$args}){
+        if($attr =~ /\A _/xms){
+            delete $args->{$attr};
+        }
+    }
+
+    return $attribute_class->new($self->name, $args);
 }
 
 sub clone_parent { # DEPRECATED
@@ -283,8 +217,7 @@ sub clone_parent { # DEPRECATED
     my %args  = ($self->get_parent_args($class, $name), @_);
 
     Carp::cluck("$self->clone_parent has been deprecated."
-        . "Use \$meta->add_attribute and \$attr->install_accessors instead.")
-        if Mouse::Util::_MOUSE_VERBOSE;
+        . "Use \$meta->add_attribute and \$attr->install_accessors instead.");
 
     $self->clone_and_inherited_args($class, $name, %args);
 }
@@ -305,80 +238,70 @@ sub get_parent_args { # DEPRECATED
 
 
 sub get_read_method {
-    $_[0]->reader || $_[0]->accessor
+    return $_[0]->reader || $_[0]->accessor
 }
 sub get_write_method {
-    $_[0]->writer || $_[0]->accessor
+    return $_[0]->writer || $_[0]->accessor
+}
+
+sub _get_accessor_method_ref {
+    my($self, $type, $generator) = @_;
+
+    my $metaclass = $self->associated_class
+        || $self->throw_error('No asocciated class for ' . $self->name);
+
+    my $accessor = $self->$type();
+    if($accessor){
+        return $metaclass->get_method_body($accessor);
+    }
+    else{
+        return $self->accessor_metaclass->$generator($self, $metaclass);
+    }
 }
 
 sub get_read_method_ref{
     my($self) = @_;
-
-    $self->{_read_method_ref} ||= do{
-        my $metaclass = $self->associated_class
-            or $self->throw_error('No asocciated class for ' . $self->name);
-
-        my $reader = $self->{reader} || $self->{accessor};
-        if($reader){
-            $metaclass->name->can($reader);
-        }
-        else{
-            $self->accessor_metaclass->_generate_reader($self, $metaclass);
-        }
-    };
+    return $self->{_read_method_ref} ||= $self->_get_accessor_method_ref('get_read_method', '_generate_reader');
 }
 
 sub get_write_method_ref{
     my($self) = @_;
-
-    $self->{_write_method_ref} ||= do{
-        my $metaclass = $self->associated_class
-            or $self->throw_error('No asocciated class for ' . $self->name);
-
-        my $reader = $self->{writer} || $self->{accessor};
-        if($reader){
-            $metaclass->name->can($reader);
-        }
-        else{
-            $self->accessor_metaclass->_generate_writer($self, $metaclass);
-        }
-    };
+    return $self->{_write_method_ref} ||= $self->_get_accessor_method_ref('get_write_method', '_generate_writer');
 }
 
-sub _canonicalize_handles {
-    my($self, $handles) = @_;
-
-    if (ref($handles) eq 'HASH') {
-        return %$handles;
-    }
-    elsif (ref($handles) eq 'ARRAY') {
-        return map { $_ => $_ } @$handles;
-    }
-    elsif (ref($handles) eq 'Regexp') {
-        my $class_or_role = ($self->{isa} || $self->{does})
-            || $self->throw_error("Cannot delegate methods based on a Regexp without a type constraint (isa)");
-
-        my $meta = Mouse::Meta::Class->initialize("$class_or_role"); # "" for stringify
-        return map  { $_ => $_ }
-               grep { !Mouse::Object->can($_) && $_ =~ $handles }
-                   Mouse::Util::is_a_metarole($meta)
-                        ? $meta->get_method_list
-                        : $meta->get_all_method_names;
-    }
-    else {
-        $self->throw_error("Unable to canonicalize the 'handles' option with $handles");
-    }
+sub set_value {
+    my($self, $object, $value) = @_;
+    return $self->get_write_method_ref()->($object, $value);
 }
 
+sub get_value {
+    my($self, $object) = @_;
+    return $self->get_read_method_ref()->($object);
+}
+
+sub has_value {
+    my($self, $object) = @_;
+    my $accessor_ref = $self->{_predicate_ref}
+        ||= $self->_get_accessor_method_ref('predicate', '_generate_predicate');
+
+    return $accessor_ref->($object);
+}
+
+sub clear_value {
+    my($self, $object) = @_;
+    my $accessor_ref = $self->{_crealer_ref}
+        ||= $self->_get_accessor_method_ref('clearer', '_generate_clearer');
+
+    return $accessor_ref->($object);
+}
+
+
 sub associate_method{
     my ($attribute, $method_name) = @_;
     $attribute->{associated_methods}++;
     return;
 }
 
-
-sub delegation_metaclass() { 'Mouse::Meta::Method::Delegation' }
-
 sub install_accessors{
     my($attribute) = @_;
 
@@ -396,20 +319,17 @@ sub install_accessors{
 
     # install delegation
     if(exists $attribute->{handles}){
-        my $delegation_class = $attribute->delegation_metaclass;
         my %handles = $attribute->_canonicalize_handles($attribute->{handles});
-        my $reader  = $attribute->get_read_method_ref;
 
-        while(my($handle_name, $method_to_call) = each %handles){
-            my $code = $delegation_class->_generate_delegation($attribute, $metaclass,
-                $reader, $handle_name, $method_to_call);
+        while(my($handle, $method_to_call) = each %handles){
+            $metaclass->add_method($handle =>
+                $attribute->_make_delegation_method(
+                    $handle, $method_to_call));
 
-            $metaclass->add_method($handle_name => $code);
-            $attribute->associate_method($handle_name);
+            $attribute->associate_method($handle);
         }
     }
 
-
     if($attribute->can('create') != \&create){
         # backword compatibility
         $attribute->create($metaclass, $attribute->name, %{$attribute});
@@ -418,6 +338,46 @@ sub install_accessors{
     return;
 }
 
+sub delegation_metaclass() { 'Mouse::Meta::Method::Delegation' }
+
+sub _canonicalize_handles {
+    my($self, $handles) = @_;
+
+    if (ref($handles) eq 'HASH') {
+        return %$handles;
+    }
+    elsif (ref($handles) eq 'ARRAY') {
+        return map { $_ => $_ } @$handles;
+    }
+    elsif ( ref($handles) eq 'CODE' ) {
+        my $class_or_role = ( $self->{isa} || $self->{does} )
+            || $self->throw_error( "Cannot find delegate metaclass for attribute " . $self->name );
+        return $handles->( $self, Mouse::Meta::Class->initialize("$class_or_role"));
+    }
+    elsif (ref($handles) eq 'Regexp') {
+        my $class_or_role = ($self->{isa} || $self->{does})
+            || $self->throw_error("Cannot delegate methods based on a Regexp without a type constraint (isa)");
+
+        my $meta = Mouse::Meta::Class->initialize("$class_or_role"); # "" for stringify
+        return map  { $_ => $_ }
+               grep { !Mouse::Object->can($_) && $_ =~ $handles }
+                   Mouse::Util::is_a_metarole($meta)
+                        ? $meta->get_method_list
+                        : $meta->get_all_method_names;
+    }
+    else {
+        $self->throw_error("Unable to canonicalize the 'handles' option with $handles");
+    }
+}
+
+sub _make_delegation_method {
+    my($self, $handle, $method_to_call) = @_;
+    my $delegator = $self->delegation_metaclass;
+    Mouse::Util::load_class($delegator);
+
+    return $delegator->_generate_delegation($self, $handle, $method_to_call);
+}
+
 sub throw_error{
     my $self = shift;
 
@@ -426,7 +386,6 @@ sub throw_error{
 }
 
 1;
-
 __END__
 
 =head1 NAME
@@ -435,7 +394,7 @@ Mouse::Meta::Attribute - The Mouse attribute metaclass
 
 =head1 VERSION
 
-This document describes Mouse version 0.40_09
+This document describes Mouse version 0.50_01
 
 =head1 METHODS
 
