@@ -81,8 +81,8 @@ sub superclasses {
 sub _reconcile_with_superclass_meta {
     my($self, $super_meta) = @_;
 
+    # find incompatible traits
     my @incompatibles;
-
     foreach my $metaclass_type(@MetaClassTypes){
         my $super_c = $super_meta->$metaclass_type();
         my $self_c  = $self->$metaclass_type();
@@ -93,9 +93,8 @@ sub _reconcile_with_superclass_meta {
     }
 
     my @roles;
-
-    foreach my $role($self->meta->calculate_all_roles){
-        if(!$super_meta->meta->does_role($role->name)){
+    foreach my $role($super_meta->meta->calculate_all_roles){
+        if(!$self->meta->does_role($role->name)){
             push @roles, $role->name;
         }
     }
@@ -194,9 +193,9 @@ sub add_attribute {
     return $attr;
 }
 
-sub compute_all_applicable_attributes {
-    Carp::cluck('compute_all_applicable_attributes() has been deprecated')
-        if Mouse::Util::_MOUSE_VERBOSE;
+sub compute_all_applicable_attributes { # DEPRECATED
+    Carp::cluck('compute_all_applicable_attributes() has been deprecated. Use get_all_attributes() instead');
+
     return shift->get_all_attributes(@_)
 }
 
@@ -207,22 +206,22 @@ sub new_object;
 sub clone_object {
     my $class  = shift;
     my $object = shift;
-    my %params = (@_ == 1) ? %{$_[0]} : @_;
+    my $args   = $object->Mouse::Object::BUILDARGS(@_);
 
     (blessed($object) && $object->isa($class->name))
         || $class->throw_error("You must pass an instance of the metaclass (" . $class->name . "), not ($object)");
 
     my $cloned = bless { %$object }, ref $object;
-    $class->_initialize_object($cloned, \%params);
+    $class->_initialize_object($cloned, $args);
 
     return $cloned;
 }
 
-sub clone_instance {
+sub clone_instance { # DEPRECATED
     my ($class, $instance, %params) = @_;
 
-    Carp::cluck('clone_instance has been deprecated. Use clone_object instead')
-        if Mouse::Util::_MOUSE_VERBOSE;
+    Carp::cluck('clone_instance() has been deprecated. Use clone_object() instead');
+
     return $class->clone_object($instance, %params);
 }
 
@@ -264,10 +263,14 @@ sub make_immutable {
     return 1;
 }
 
-sub make_mutable { not_supported }
+sub make_mutable {
+    my($self) = @_;
+    $self->{is_immutable} = 0;
+    return;
+}
 
-sub is_immutable {  $_[0]->{is_immutable} }
-sub is_mutable   { !$_[0]->{is_immutable} }
+sub is_immutable;
+sub is_mutable   { !$_[0]->is_immutable }
 
 sub _install_modifier_pp{
     my( $self, $type, $name, $code ) = @_;
@@ -341,7 +344,7 @@ sub _install_modifier {
     # load Class::Method::Modifiers first
     my $no_cmm_fast = do{
         local $@;
-        eval q{ require Class::Method::Modifiers::Fast };
+        eval q{ use Class::Method::Modifiers::Fast 0.041 () };
         $@;
     };
 
@@ -350,7 +353,7 @@ sub _install_modifier {
         $impl = \&_install_modifier_pp;
     }
     else{
-        my $install_modifier = Class::Method::Modifiers::Fast->can('_install_modifier');
+        my $install_modifier = Class::Method::Modifiers::Fast->can('install_modifier');
         $impl = sub {
             my ( $self, $type, $name, $code ) = @_;
             my $into = $self->name;
@@ -458,7 +461,7 @@ Mouse::Meta::Class - The Mouse class metaclass
 
 =head1 VERSION
 
-This document describes Mouse version 0.40_09
+This document describes Mouse version 0.50_01
 
 =head1 METHODS
 
