@@ -1,13 +1,15 @@
 package Mouse::Meta::Method::Accessor;
 use Mouse::Util qw(:meta); # enables strict and warnings
+use warnings FATAL => 'recursion';
+
 
 sub _inline_slot{
     my(undef, $self_var, $attr_name) = @_;
     return sprintf '%s->{q{%s}}', $self_var, $attr_name;
 }
 
-sub _generate_accessor{
-    my ($method_class, $attribute, $class, $type) = @_;
+sub _generate_accessor_any{
+    my($method_class, $type, $attribute, $class) = @_;
 
     my $name          = $attribute->name;
     my $default       = $attribute->default;
@@ -23,13 +25,11 @@ sub _generate_accessor{
     my $self  = '$_[0]';
     my $slot  = $method_class->_inline_slot($self, $name);;
 
-    $type ||= 'accessor';
-
-    my $accessor = sprintf(qq{package %s;\n#line 1 "%s for %s (%s)"\n}, $class->name, $type, $name, __FILE__)
+    my $accessor = sprintf(qq{package %s;\n#line 1 "%s-accessor for %s (%s)"\n}, $class->name, $type, $name, __FILE__)
                  . "sub {\n";
 
-    if ($type eq 'accessor' || $type eq 'writer') {
-        if($type eq 'accessor'){
+    if ($type eq 'rw' || $type eq 'wo') {
+        if($type eq 'rw'){
             $accessor .= 
                 'if (scalar(@_) >= 2) {' . "\n";
         }
@@ -51,7 +51,7 @@ sub _generate_accessor{
             $accessor .= 
                 "\n".
                 '$compiled_type_constraint->('.$value.') or
-                    $attribute->verify_type_constraint_error($name, '.$value.', $constraint);' . "\n";
+                    $attribute->_throw_type_constraint_error('.$value.', $constraint);' . "\n";
         }
 
         # if there's nothing left to do for the attribute we can return during
@@ -70,7 +70,7 @@ sub _generate_accessor{
 
         $accessor .= "}\n";
     }
-    elsif($type eq 'reader') {
+    elsif($type eq 'ro') {
         $accessor .= 'Carp::confess("Cannot assign a value to a read-only accessor") if scalar(@_) >= 2;' . "\n";
     }
     else{
@@ -98,7 +98,7 @@ sub _generate_accessor{
             $accessor .= "my \$tmp = $value;\n";
 
             $accessor .= "\$compiled_type_constraint->(\$tmp)";
-            $accessor .= " || \$attribute->verify_type_constraint_error(\$name, \$tmp, \$constraint);\n";
+            $accessor .= " || \$attribute->_throw_type_constraint_error(\$tmp, \$constraint);\n";
             $accessor .= "$slot = \$tmp;\n";
         }
         else{
@@ -136,16 +136,20 @@ sub _generate_accessor{
     return $code;
 }
 
-sub _generate_reader{
+sub _generate_accessor{
     my $class = shift;
-    return $class->_generate_accessor(@_, 'reader');
+    return $class->_generate_accessor_any(rw => @_);
 }
 
-sub _generate_writer{
+sub _generate_reader {
     my $class = shift;
-    return $class->_generate_accessor(@_, 'writer');
+    return $class->_generate_accessor_any(ro => @_);
 }
 
+sub _generate_writer {
+    my $class = shift;
+    return $class->_generate_accessor_any(wo => @_);
+}
 
 sub _generate_predicate {
     my (undef, $attribute, $class) = @_;
@@ -160,8 +164,7 @@ sub _generate_clearer {
     my (undef, $attribute, $class) = @_;
 
     my $slot = $attribute->name;
-
-   return sub{
+    return sub{
         delete $_[0]->{$slot};
     };
 }
@@ -175,7 +178,7 @@ Mouse::Meta::Method::Accessor - A Mouse method generator for accessors
 
 =head1 VERSION
 
-This document describes Mouse version 0.40_09
+This document describes Mouse version 0.50_01
 
 =head1 SEE ALSO
 
