@@ -24,13 +24,6 @@ sub new {
 
     my $check = delete $args{optimized};
 
-    if($args{_compiled_type_constraint}){
-        Carp::cluck("'_compiled_type_constraint' has been deprecated, use 'optimized' instead")
-            if Mouse::Util::_MOUSE_VERBOSE;
-
-        $check = $args{_compiled_type_constraint};
-    }
-
     if($check){
         $args{hand_optimized_type_constraint} = $check;
         $args{compiled_type_constraint}       = $check;
@@ -47,25 +40,7 @@ sub new {
     my $self = bless \%args, $class;
     $self->compile_type_constraint() if !$self->{hand_optimized_type_constraint};
 
-    if($self->{type_constraints}){ # Union
-        my @coercions;
-        foreach my $type(@{$self->{type_constraints}}){
-            if($type->has_coercion){
-                push @coercions, $type;
-            }
-        }
-        if(@coercions){
-            $self->{_compiled_type_coercion} = sub {
-                my($thing) = @_;
-                foreach my $type(@coercions){
-                    my $value = $type->coerce($thing);
-                    return $value if $self->check($value);
-                }
-                return $thing;
-            };
-        }
-    }
-
+    $self->_compile_union_type_coercion() if $self->{type_constraints};
     return $self;
 }
 
@@ -88,6 +63,15 @@ sub create_child_type{
    );
 }
 
+sub name;
+sub parent;
+sub message;
+sub has_coercion;
+sub _compiled_type_constraint;
+sub _compiled_type_coercion;
+
+sub compile_type_constraint;
+
 sub _add_type_coercions{
     my $self = shift;
 
@@ -113,16 +97,47 @@ sub _add_type_coercions{
         Carp::confess("Cannot add additional type coercions to Union types");
     }
     else{
+        $self->_compile_type_coercion();
+    }
+    return;
+}
+
+sub _compile_type_coercion {
+    my($self) = @_;
+
+    my @coercions = @{$self->{_coercion_map}};
+
+    $self->{_compiled_type_coercion} = sub {
+       my($thing) = @_;
+       foreach my $pair (@coercions) {
+            #my ($constraint, $converter) = @$pair;
+            if ($pair->[0]->check($thing)) {
+              local $_ = $thing;
+              return $pair->[1]->($thing);
+            }
+       }
+       return $thing;
+    };
+    return;
+}
+
+sub _compile_union_type_coercion {
+    my($self) = @_;
+
+    my @coercions;
+    foreach my $type(@{$self->{type_constraints}}){
+        if($type->has_coercion){
+            push @coercions, $type;
+        }
+    }
+    if(@coercions){
         $self->{_compiled_type_coercion} = sub {
-           my($thing) = @_;
-           foreach my $pair (@{$coercions}) {
-                #my ($constraint, $converter) = @$pair;
-                if ($pair->[0]->check($thing)) {
-                  local $_ = $thing;
-                  return $pair->[1]->($thing);
-                }
-           }
-           return $thing;
+            my($thing) = @_;
+            foreach my $type(@coercions){
+                my $value = $type->coerce($thing);
+                return $value if $self->check($value);
+            }
+            return $thing;
         };
     }
     return;
@@ -136,10 +151,14 @@ sub check {
 sub coerce {
     my $self = shift;
 
+    my $coercion = $self->_compiled_type_coercion;
+    if(!$coercion){
+        Carp::confess("Cannot coerce without a type coercion");
+    }
+
     return $_[0] if $self->_compiled_type_constraint->(@_);
 
-    my $coercion = $self->_compiled_type_coercion;
-    return $coercion ? $coercion->(@_) : $_[0];
+    return  $coercion->(@_);
 }
 
 sub get_message {
@@ -210,7 +229,7 @@ Mouse::Meta::TypeConstraint - The Mouse Type Constraint metaclass
 
 =head1 VERSION
 
-This document describes Mouse version 0.40_09
+This document describes Mouse version 0.50_01
 
 =head1 DESCRIPTION
 
