@@ -38,7 +38,7 @@ BEGIN{
     # Because Mouse::Util is loaded first in all the Mouse sub-modules,
     # XS loader is placed here, not in Mouse.pm.
 
-    our $VERSION = '0.40_09';
+    our $VERSION = '0.50_01';
 
     my $xs = !(exists $INC{'Mouse/PurePerl.pm'} || $ENV{MOUSE_PUREPERL});
 
@@ -54,7 +54,7 @@ BEGIN{
             Mouse::Util->import({ into => 'Mouse::Meta::Method::Destructor::XS'  }, ':meta');
             Mouse::Util->import({ into => 'Mouse::Meta::Method::Accessor::XS'    }, ':meta');
             return 1;
-        };
+        } || 0;
         #warn $@ if $@;
     }
 
@@ -65,7 +65,6 @@ BEGIN{
     *MOUSE_XS = sub(){ $xs };
 }
 
-
 use Carp         ();
 use Scalar::Util ();
 
@@ -82,9 +81,14 @@ BEGIN {
     *get_all_metaclass_names     = \&Mouse::Meta::Module::_get_all_metaclass_names;
 
     # is-a predicates
-    generate_isa_predicate_for('Mouse::Meta::TypeConstraint' => 'is_a_type_constraint');
-    generate_isa_predicate_for('Mouse::Meta::Class'          => 'is_a_metaclass');
-    generate_isa_predicate_for('Mouse::Meta::Role'           => 'is_a_metarole');
+    #generate_isa_predicate_for('Mouse::Meta::TypeConstraint' => 'is_a_type_constraint');
+    #generate_isa_predicate_for('Mouse::Meta::Class'          => 'is_a_metaclass');
+    #generate_isa_predicate_for('Mouse::Meta::Role'           => 'is_a_metarole');
+
+    # duck type predicates
+    generate_can_predicate_for(['_compiled_type_constraint']  => 'is_a_type_constraint');
+    generate_can_predicate_for(['create_anon_class']          => 'is_a_metaclass');
+    generate_can_predicate_for(['create_anon_role']           => 'is_a_metarole');
 }
 
 our $in_global_destruction = 0;
@@ -141,13 +145,14 @@ BEGIN {
         # See also MRO::Compat::__get_linear_isa.
         $get_linear_isa = sub ($;$){
             my($classname, $type) = @_;
+            package # hide from PAUSE
+                Class::C3;
             if(!defined $type){
-                package Class::C3;
                 our %MRO;
                 $type = exists $MRO{$classname} ? 'c3' : 'dfs';
             }
             return $type eq 'c3'
-                ? [Class::C3::calculateMRO($classname)]
+                ? [calculateMRO($classname)]
                 : $_get_linear_isa_dfs->($classname);
         };
     }
@@ -260,9 +265,8 @@ sub load_class {
 
 sub is_class_loaded;
 
-
 sub apply_all_roles {
-    my $applicant = Scalar::Util::blessed($_[0])
+    my $consumer = Scalar::Util::blessed($_[0])
         ?                                shift   # instance
         : Mouse::Meta::Class->initialize(shift); # class or role name
 
@@ -280,15 +284,15 @@ sub apply_all_roles {
         load_class($role_name);
 
         is_a_metarole( get_metaclass_by_name($role_name) )
-            || $applicant->meta->throw_error("You can only consume roles, $role_name is not a Mouse role");
+            || $consumer->meta->throw_error("You can only consume roles, $role_name is not a Mouse role");
     }
 
     if ( scalar @roles == 1 ) {
         my ( $role_name, $params ) = @{ $roles[0] };
-        get_metaclass_by_name($role_name)->apply( $applicant, defined $params ? $params : () );
+        get_metaclass_by_name($role_name)->apply( $consumer, defined $params ? $params : () );
     }
     else {
-        Mouse::Meta::Role->combine(@roles)->apply($applicant);
+        Mouse::Meta::Role->combine(@roles)->apply($consumer);
     }
     return;
 }
@@ -306,6 +310,9 @@ sub english_list {
     return join q{, }, @items, "and $tail";
 }
 
+sub quoted_english_list {
+    return english_list(map { qq{'$_'} } @_);
+}
 
 # common utilities
 
@@ -329,17 +336,17 @@ sub dump :method {
 
     require 'Data/Dumper.pm'; # we don't want to create its namespace
     my $dd = Data::Dumper->new([$self]);
-    $dd->Maxdepth(defined($maxdepth) ? $maxdepth : 2);
+    $dd->Maxdepth(defined($maxdepth) ? $maxdepth : 3);
     $dd->Indent(1);
     return $dd->Dump();
 }
 
 # general does() method
-sub does :method;
-*does = \&does_role; # alias
+sub does :method {
+    goto &does_role;
+}
 
 1;
-
 __END__
 
 =head1 NAME
@@ -348,7 +355,7 @@ Mouse::Util - Features, with or without their dependencies
 
 =head1 VERSION
 
-This document describes Mouse version 0.40_09
+This document describes Mouse version 0.50_01
 
 =head1 IMPLEMENTATIONS FOR
 
@@ -394,10 +401,14 @@ C<eval "use $module"> or using C<require>.
 
 =head3 C<get_code_info>
 
-=head1 UTILITIES FOR MOUSE
+=head1 Mouse specific utilities
 
 =head3 C<not_supported>
 
+=head3 C<get_code_package>
+
+=head3 C<get_code_ref>
+
 =head1 SEE ALSO
 
 L<Moose::Util>
